import { useState, type ReactElement, } from 'react'
import { useForm, type SubmitHandler } from 'react-hook-form'
import ImageWithPreview from './ImageWithPrview'
import { Post } from './api'
import { ShowCred } from './ShowCred'

type Inputs = {
  content: string
  signing?: string
  files?: FileList
}

export default function PostForm() {
  const {
    register,
    handleSubmit,
    watch,
    setValue,
    reset,
    formState: { errors },
  } = useForm<Inputs>()
  const onSubmit: SubmitHandler<Inputs> = (data) => {
    setPosting(true)
    console.log(data)
    Post(data).then((e) => setCred(e)).finally(() => setPosting(false))
  }

  const files_list = watch('files', undefined)
  const iter_file_list = (
    li: FileList,
    callback: (f: File, id: number) => any
  ) => {
    let agg = []
    let id = 0
    for (const f of li) {
      agg.push(callback(f, id))
      id += 1
    }
    return agg
  }
  const img_list: Array<ReactElement> = files_list
    ? iter_file_list(files_list, (f, id) => {
      return (
        <ImageWithPreview
          key={id}
          src={URL.createObjectURL(f)}
          remove={() => {
            const dt = new DataTransfer()
            for (const file of files_list) {
              if (f != file) {
                dt.items.add(file)
              }
            }
            setValue('files', dt.files)
          }}
        />
      )
    })
    : []
  const [cred, setCred] = useState<{ id: number; hash: string } | undefined>(
    undefined
  )
  const [posting, setPosting] = useState(false)

  return (
    <>
      {cred !== undefined && (
        <ShowCred
          id={cred.id}
          hash={cred.hash}
          close={() => {
            setCred(undefined)
            reset()
          }}
        />
      )}
      <form
        onSubmit={handleSubmit(onSubmit)}
        className={
          'flex flex-col m-auto w-10/12 h-[80dvh] px-10 gap-3 pb-3 md:w-[50dvw]' +
          (cred !== undefined ? ' hidden' : '')
        }
      >
        {/* register your input into the hook by invoking the "register" function */}
        <h1 className="text-3xl my-3">發佈匿名</h1>
        <textarea
          className="ring-3 ring-zinc-500 focus:ring-zinc-200 outline-none rounded-xl h-5/12 px-3 w-full"
          placeholder="匿名文章"
          {...register('content', { required: true })}
        />
        <div>
          <label htmlFor="files" className="text-xl">
            圖片
          </label>
          <input
            multiple
            id="files"
            type="file"
            accept="image/png, image/jpeg, image/gif, image/webp, image/heif"
            className="hidden"
            {...register('files')}
          />
          <div
            className={
              'h-20 w-full gap-3 overflow-scroll flex flex-row ' +
              (files_list && files_list.length > 0 ? '' : 'hidden')
            }
          >
            {...img_list}
          </div>
        </div>

        {/* include validation with required or other standard HTML validation rules */}
        <div className="ml-auto flex gap-3">
          <label className="w-fit break-keep">署名</label>
          <input
            className="border-b-4 border-zinc-500 w-full text-end outline-none focus:border-zinc-200"
            {...register('signing', {
              maxLength: 20,
            })}
          />
        </div>
        {/* errors will return when field validation fails  */}
        {errors.content && <span>This field is required</span>}

        <button type="submit" className="ring-3 w-full mx-auto rounded-md " disabled={posting}>
          發送
        </button>
      </form>
    </>
  )
}
