import { useEffect } from 'react'
import { getCookie, setCookie } from 'typescript-cookie'

export const ShowCred = ({
  id,
  hash,
  close,
}: {
  id: number
  hash: string
  close: () => void
}) => {
  const copy = () => {
    navigator.clipboard.writeText(`${id}:${hash}`)
  }
  useEffect(() => {
    let cred = getCookie('post_cred')
    if (cred) {
      let parsed: { id: number; hash: string }[] = JSON.parse(cred)
      if (parsed.findIndex(f => f.id == id) == -1) {
        parsed.push({ id, hash })
      }
      setCookie('post_cred', JSON.stringify(parsed))
    } else {
      setCookie('post_cred', JSON.stringify([{ id, hash }]))
    }
  }, [])

  return (
    <div className="flex flex-col h-1/2 w-[80dvw]">
      <h1 className="text-2xl">已成功發文！</h1>
      <h3>
        PID: <span className="bg-zinc-500 px-2 w-fit mx-auto">{id}</span>
      </h3>
      <h3>
        HASH:{' '}
        <span className="bg-zinc-500 px-2 inline-block text-ellipsis w-8/12 overflow-hidden text-nowrap">
          {hash}
        </span>
      </h3>
      <button onClick={copy} className="border-2 rounded-lg w-fit mx-auto">
        複製
      </button>
      <p className="text-red-300 text-sm">
        請保存好HASH，如要刪文需要使用HASH值(已自動保存於Cookie)
      </p>
      <button type="button" onClick={close}>
        關閉
      </button>
    </div>
  )
}
